@@ -8,21 +8,23 @@
 #'
 #' @return vector containing all the links in the page
 #'
+#' @export
+#'
 #' @examples
 #' \dontrun{
 #'   # Retrieve mopex daily catalogue
 #'   url <- "ftp://hydrology.nws.noaa.gov/pub/gcip/mopex/US_Data/Us_438_Daily"
-#'   getContent(url)
+#'   getContent(dirs = url)
 #' }
 #'
 
 getContent <- function(dirs) {
 
-  urls <- paste(dirs, "/", sep="")
-  fls <- strsplit(RCurl::getURL(urls, dirlistonly=TRUE), "\n")
-  ok <- sapply(fls, length) > 0
-  links <- unlist(mapply(paste, urls[ok], fls[ok], sep="", SIMPLIFY=FALSE),
-                  use.names=FALSE)
+  urls <- paste(dirs, "/", sep = "")
+  fls <- strsplit(RCurl::getURL(urls, dirlistonly = TRUE), "\n")
+  ok <- vapply(fls, length) > 0
+  links <- unlist(mapply(paste, urls[ok], fls[ok], sep = "", SIMPLIFY = FALSE),
+                  use.names = FALSE)
 
   return(links)
 
